unit Main;

interface

uses
    Windows,
    Messages,
    SysUtils,
    Classes,
    Graphics,
    Controls,
    Forms,
    Dialogs,
    GL,
    GLClass,
    GLTexture,
    GLUI,
    GLText,
    Camera,
    ExtCtrls;

type
  TMainForm = class(TForm)
    RenderTimer: TTimer;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure RenderTimerTimer(Sender: TObject);
    procedure FormMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure FormMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
  private
    { Private declarations }
    procedure SetGLStateVariables;
    procedure ButtonClick(Sender:TUIElement);
    procedure RadioClick(Sender:TUIElement);
  public
    { Public declarations }
    GL:TOpenGL;
    Button:TRolloverButton;
    Radio:TRollOverCheckBox;
    UIManager:TUIManager;
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

procedure TMainForm.FormCreate(Sender: TObject);
begin
     GL:=TOpenGL.Create(Self);
     GL.FullScreen:=false;
     GL.InitGL;

     Button:=TRollOverButton.Create;
     Button.BackTex.LoadTexture('crsr_2.TGA');
     Button.ForeTex.LoadTexture('crsr_2_selected.TGA');
     Button.DisabledTex.LoadTexture('crsr_2_disabled.TGA');

     Button.X:=10;
     Button.Y:=10;
     Button.Width:=64;
     Button.Height:=64;
     Button.OnClick:=ButtonClick;

     Radio:=TRollOverCheckBox.Create;
     Radio.BackTex.LoadTexture('tiny_box.tga');
     Radio.ForeTex:=Radio.BackTex;
     Radio.CheckedTex.LoadTexture('tiny_box_selected.tga');
     Radio.X:=10;
     Radio.Y:=100;
     Radio.Width:=32;
     Radio.Height:=32;
     Radio.OnClick:=RadioClick;

     UIManager:=TUIManager.Create;
     UIManager.Elements.Add(Button);
     UIManager.Elements.Add(Radio);

     SetGLStateVariables;

     RenderTimer.Enabled:=true;
end;

procedure TMainForm.FormDestroy(Sender: TObject);
begin
     RenderTimer.Enabled:=false;

     Button.Free;

     GL.Free;
end;

procedure TMainForm.RenderTimerTimer(Sender: TObject);
begin
     GL.ClearAll;

     Setup2DScreen(ClientWidth,ClientHeight);

     UIManager.Render;

     GL.Flip;
end;

procedure TMainForm.SetGLStateVariables;
begin
     glDisable(GL_DEPTH_TEST);
     glDisable(GL_LIGHTING);
     glEnable(GL_TEXTURE_2D);
     glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
     glEnable(GL_BLEND);
end;

procedure TMainForm.FormMouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
begin
     UIManager.MouseMove(X,Y);
end;

procedure TMainForm.ButtonClick(Sender: TUIElement);
begin
     ShowMessage('You clicked the button');
end;

procedure TMainForm.FormMouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
     UIManager.MouseClick(X,Y,Button);
end;

procedure TMainForm.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
     case Key of
          VK_ESCAPE:Close;
     end;
end;

procedure TMainForm.RadioClick(Sender: TUIElement);
begin
     Button.Enabled:=not Button.Enabled;
end;

end.
